---
title: <span class="badge builder"></span> ScatterSeriesConfig
---
# <span class="badge builder"></span> ScatterSeriesConfig

## Constructor

```python
ScatterSeriesConfig()
```
## Methods

### <span class="badge object-method"></span> build

Builds the object.

```python
def build() -> xychart.ScatterSeriesConfig
```

### <span class="badge object-method"></span> axis_border_show

```python
def axis_border_show(axis_border_show: bool) -> typing.Self
```

### <span class="badge object-method"></span> axis_centered_zero

```python
def axis_centered_zero(axis_centered_zero: bool) -> typing.Self
```

### <span class="badge object-method"></span> axis_color_mode

```python
def axis_color_mode(axis_color_mode: common.AxisColorMode) -> typing.Self
```

### <span class="badge object-method"></span> axis_grid_show

```python
def axis_grid_show(axis_grid_show: bool) -> typing.Self
```

### <span class="badge object-method"></span> axis_label

```python
def axis_label(axis_label: str) -> typing.Self
```

### <span class="badge object-method"></span> axis_placement

```python
def axis_placement(axis_placement: common.AxisPlacement) -> typing.Self
```

### <span class="badge object-method"></span> axis_soft_max

```python
def axis_soft_max(axis_soft_max: float) -> typing.Self
```

### <span class="badge object-method"></span> axis_soft_min

```python
def axis_soft_min(axis_soft_min: float) -> typing.Self
```

### <span class="badge object-method"></span> axis_width

```python
def axis_width(axis_width: float) -> typing.Self
```

### <span class="badge object-method"></span> hide_from

```python
def hide_from(hide_from: cogbuilder.Builder[common.HideSeriesConfig]) -> typing.Self
```

### <span class="badge object-method"></span> label

```python
def label(label: common.VisibilityMode) -> typing.Self
```

### <span class="badge object-method"></span> label_value

```python
def label_value(label_value: cogbuilder.Builder[common.TextDimensionConfig]) -> typing.Self
```

### <span class="badge object-method"></span> line_color

```python
def line_color(line_color: cogbuilder.Builder[common.ColorDimensionConfig]) -> typing.Self
```

### <span class="badge object-method"></span> line_style

```python
def line_style(line_style: cogbuilder.Builder[common.LineStyle]) -> typing.Self
```

### <span class="badge object-method"></span> line_width

```python
def line_width(line_width: int) -> typing.Self
```

### <span class="badge object-method"></span> name

```python
def name(name: str) -> typing.Self
```

### <span class="badge object-method"></span> point_color

```python
def point_color(point_color: cogbuilder.Builder[common.ColorDimensionConfig]) -> typing.Self
```

### <span class="badge object-method"></span> point_size

```python
def point_size(point_size: cogbuilder.Builder[common.ScaleDimensionConfig]) -> typing.Self
```

### <span class="badge object-method"></span> scale_distribution

```python
def scale_distribution(scale_distribution: cogbuilder.Builder[common.ScaleDistributionConfig]) -> typing.Self
```

### <span class="badge object-method"></span> show

```python
def show(show: xychart.ScatterShow) -> typing.Self
```

### <span class="badge object-method"></span> x

```python
def x(x: str) -> typing.Self
```

### <span class="badge object-method"></span> y

```python
def y(y: str) -> typing.Self
```

## See also

 * <span class="badge object-type-class"></span> [ScatterSeriesConfig](./object-ScatterSeriesConfig.md)
